@@ -220,8 +220,12 @@ def _validate_units_consistency(objs):
     # because it's already a necessary condition for numpy to use our
     # custom implementations
     units = get_units(objs)
-    unique_units = set(units)
-    if len(unique_units) == 1 or all(u.is_dimensionless for u in unique_units):
+
+    # filtering unique units using equality comparison implicitly allows for units
+    # which have a dimensionless**(n) component to be treated as one and the same
+    unique_units = [units[0], *(u for u in units if u != units[0])]
+
+    if len(unique_units) == 1:
         return units[0]
     else:
         raise UnitInconsistencyError(*units)
@@ -952,29 +956,38 @@ def array_repr(arr, *args, **kwargs):
 
 if NUMPY_VERSION < Version("2.0.0dev0"):
     # functions that are removed in numpy 2.0.0
-    @implements(np.asfarray)
+    @implements(np.asfarray)  # noqa: NPY201
     def asfarray(a, dtype=np.double):
         ret_units = a.units
-        return np.asfarray._implementation(np.asarray(a), dtype=dtype) * ret_units
+        arr = np.asfarray._implementation(np.asarray(a), dtype=dtype)  # noqa: NPY201
+        return arr * ret_units
+
+    _trapezoid_func = np.trapz
+
+elif NUMPY_VERSION >= Version("2.0.0dev0"):
+    # functions that were added in numpy 2.0.0
+    @implements(np.linalg.outer)
+    def linalg_outer(x1, x2, /):
+        return product_helper(x1, x2, out=None, func=np.linalg.outer)
+
+    _trapezoid_func = np.trapezoid
 
 
-# functions with pending deprecations
-if hasattr(np, "trapz"):
-
-    @implements(np.trapz)
-    def trapz(y, x=None, dx=1.0, *args, **kwargs):
-        ret_units = y.units
-        if x is None:
-            ret_units = ret_units * getattr(dx, "units", NULL_UNIT)
-        else:
-            ret_units = ret_units * getattr(x, "units", NULL_UNIT)
-        if isinstance(x, np.ndarray):
-            x = np.asarray(x)
-        if isinstance(dx, np.ndarray):
-            dx = np.asarray(dx)
-        return (
-            np.trapz._implementation(np.asarray(y), x, dx, *args, **kwargs) * ret_units
-        )
+@implements(_trapezoid_func)
+def trapezoid(y, x=None, dx=1.0, *args, **kwargs):
+    ret_units = y.units
+    if x is None:
+        ret_units = ret_units * getattr(dx, "units", NULL_UNIT)
+    else:
+        ret_units = ret_units * getattr(x, "units", NULL_UNIT)
+    if isinstance(x, np.ndarray):
+        x = np.asarray(x)
+    if isinstance(dx, np.ndarray):
+        dx = np.asarray(dx)
+    return (
+        _trapezoid_func._implementation(np.asarray(y), x, dx, *args, **kwargs)
+        * ret_units
+    )
 
 
 if hasattr(np, "in1d"):
