@@ -5,12 +5,12 @@ unyt_array class.
 
 """
 
-
 import copy
 import re
 import sys
 import warnings
 from functools import lru_cache
+from importlib.metadata import version
 from numbers import Number as numeric_type
 
 import numpy as np
@@ -27,6 +27,7 @@ from numpy import (
     bitwise_and,
     bitwise_or,
     bitwise_xor,
+    cbrt,
     ceil,
     clip,
     conj,
@@ -102,6 +103,7 @@ from numpy import (
     true_divide,
     trunc,
 )
+from packaging.version import Version
 from sympy import Rational
 
 from unyt._on_demand_imports import _astropy, _dask, _pint
@@ -146,6 +148,8 @@ __doctest_requires__ = {
     ("unyt_array.from_astropy", "unyt_array.to_astropy"): ["astropy"],
 }
 
+_COPY_IF_NEEDED = None if Version(version("numpy")) >= Version("2.0.0dev0") else False
+
 # This is partially adapted from the following SO thread
 # https://stackoverflow.com/questions/41668588/regex-to-match-scientific-notation
 _NUMB_PATTERN = (
@@ -173,6 +177,11 @@ def _sqrt_unit(unit):
     return 1, unit**0.5
 
 
+@lru_cache(maxsize=128, typed=False)
+def _cbrt_unit(unit):
+    return 1, unit ** (1.0 / 3.0)
+
+
 @lru_cache(maxsize=128, typed=False)
 def _multiply_units(unit1, unit2):
     try:
@@ -340,6 +349,7 @@ unary_operators = (
     expm1,
     log1p,
     sqrt,
+    cbrt,
     square,
     reciprocal,
     sin,
@@ -505,6 +515,7 @@ class unyt_array(np.ndarray):
         expm1: _return_without_unit,
         log1p: _return_without_unit,
         sqrt: _sqrt_unit,
+        cbrt: _cbrt_unit,
         square: _square_unit,
         reciprocal: _reciprocal_unit,
         sin: _return_without_unit,
@@ -1978,7 +1989,7 @@ class unyt_array(np.ndarray):
                     "added to unyt_array." % (str(ufunc), len(inputs))
                 )
         if unit is None:
-            out_arr = np.array(out_arr, copy=False)
+            out_arr = np.array(out_arr, copy=_COPY_IF_NEEDED)
         elif ufunc in (modf, divmod_):
             out_arr = tuple(ret_class(o, unit) for o in out_arr)
         elif out_arr.shape == ():
