@@ -4,6 +4,7 @@ from importlib.metadata import version
 
 import numpy as np
 import pytest
+from numpy.testing import assert_allclose
 from packaging.version import Version
 
 from unyt import A, K, cm, degC, delta_degC, g, km, rad, s
@@ -153,9 +154,25 @@ NOOP_FUNCTIONS = {
 
 
 if NUMPY_VERSION >= Version("2.0.0dev0"):
+    # the followin all work out of the box (tested)
     NOOP_FUNCTIONS |= {
-        np.linalg.diagonal,  # works out of the box (tested)
-        np.linalg.trace,  # works out of the box (tested)
+        np.linalg.cross,
+        np.linalg.diagonal,
+        np.linalg.matmul,
+        np.linalg.matrix_norm,
+        np.linalg.matrix_transpose,
+        np.linalg.svdvals,
+        np.linalg.tensordot,
+        np.linalg.trace,
+        np.linalg.vecdot,
+        np.linalg.vector_norm,
+        np.astype,
+        np.matrix_transpose,
+        np.unique_all,
+        np.unique_counts,
+        np.unique_inverse,
+        np.unique_values,
+        np.vecdot,
     }
 
 # Functions for which behaviour is intentionally left to default
@@ -284,6 +301,15 @@ def test_unit_validation(arrays):
     assert res.units.is_dimensionless
 
 
+def test_unit_validation_dimensionless_factors():
+    # see https://github.com/yt-project/unyt/issues/477
+    # numpy.concatenate isn't essential to this test
+    # what we're really testing is the unit consistency validation
+    # underneath, but we do so using public API
+    res = np.concatenate([[1] * cm, unyt_array([1], "cm*dimensionless")])
+    assert res.units is cm
+
+
 def test_array_repr():
     arr = [1, 2, 3] * cm
     assert re.fullmatch(r"unyt_array\(\[1, 2, 3\], (units=)?'cm'\)", np.array_repr(arr))
@@ -415,7 +441,8 @@ def test_kron():
 
 
 def test_linalg_inv():
-    arr = np.random.random_sample((3, 3)) * cm
+    rng = np.random.default_rng()
+    arr = rng.random((3, 3)) * cm
     iarr = np.linalg.inv(arr)
     assert 1 * iarr.units == 1 / cm
 
@@ -428,7 +455,8 @@ def test_linalg_tensorinv():
 
 
 def test_linalg_pinv():
-    a = np.random.randn(9, 6) * cm
+    rng = np.random.default_rng()
+    a = rng.standard_normal(size=(9, 6)) * cm
     B = np.linalg.pinv(a)
     assert 1 * B.units == 1 / cm
     np.testing.assert_allclose(a, np.dot(a, np.dot(B, a)))
@@ -487,8 +515,113 @@ def test_linalg_trace():
     assert b.units == a.units
 
 
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"), reason="linalg.outer is new in numpy 2.0"
+)
+def test_linalg_outer():
+    a = np.arange(10) * cm
+    assert_array_equal_units(np.linalg.outer(a, a), np.outer(a, a))
+
+
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"), reason="linalg.cross is new in numpy 2.0"
+)
+def test_linalg_cross():
+    a = np.arange(3) * cm
+    assert_array_equal_units(np.linalg.cross(a, a), np.cross(a, a))
+
+
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"), reason="linalg.matmul is new in numpy 2.0"
+)
+def test_linalg_matmul():
+    a = np.eye(3) * cm
+    assert_array_equal_units(np.linalg.matmul(a, a), np.matmul(a, a))
+
+
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"),
+    reason="linalg.matrix_norm is new in numpy 2.0",
+)
+def test_linalg_matrix_norm():
+    a = np.eye(3) * cm
+    assert_array_equal_units(np.linalg.matrix_norm(a), np.linalg.norm(a))
+
+
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"), reason="matrix_transpose is new in numpy 2.0"
+)
+@pytest.mark.parametrize("namespace", [None, "linalg"])
+def test_matrix_transpose(namespace):
+    if namespace is None:
+        func = np.matrix_transpose
+    else:
+        func = getattr(np, namespace).matrix_transpose
+    a = np.arange(0, 9).reshape(3, 3)
+    assert_array_equal_units(func(a), np.transpose(a))
+
+
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"), reason="vecdot is new in numpy 2.0"
+)
+@pytest.mark.parametrize("namespace", [None, "linalg"])
+def test_vecdot(namespace):
+    if namespace is None:
+        func = np.vecdot
+    else:
+        func = getattr(np, namespace).vecdot
+    a = np.arange(0, 9)
+    assert_array_equal_units(func(a, a), np.vdot(a, a))
+
+
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"),
+    reason="linalg.vector_norm is new in numpy 2.0",
+)
+def test_linalg_vector_norm():
+    a = np.arange(0, 9)
+    assert_array_equal_units(np.linalg.vector_norm(a), np.linalg.norm(a))
+
+
+def test_linalg_svd():
+    rng = np.random.default_rng()
+    a = (rng.standard_normal(size=(9, 6)) + 1j * rng.standard_normal(size=(9, 6))) * cm
+    u, s, vh = np.linalg.svd(a)
+    assert type(u) is np.ndarray
+    assert type(vh) is np.ndarray
+    assert type(s) is unyt_array
+    assert s.units == cm
+
+    s = np.linalg.svd(a, compute_uv=False)
+    assert type(s) is unyt_array
+    assert s.units == cm
+
+
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"), reason="linalg.svdvals is new in numpy 2.0"
+)
+def test_linalg_svdvals():
+    q = np.arange(9).reshape(3, 3) * cm
+
+    _, ref, _ = np.linalg.svd(q)
+    res = np.linalg.svdvals(q)
+    assert type(res) is unyt_array
+    assert_allclose(res, ref, rtol=5e-16)
+
+
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"), reason="linalg.tensordot is new in numpy 2.0"
+)
+def test_linalg_tensordot():
+    q = np.arange(9).reshape(3, 3) * cm
+    ref = np.tensordot(q, q)
+    res = np.linalg.tensordot(q, q)
+    assert_array_equal_units(res, ref)
+
+
 def test_histogram():
-    arr = np.random.normal(size=1000) * cm
+    rng = np.random.default_rng()
+    arr = rng.normal(size=1000) * cm
     counts, bins = np.histogram(arr, bins=10, range=(arr.min(), arr.max()))
     assert type(counts) is np.ndarray
     assert bins.units == arr.units
@@ -496,15 +629,17 @@ def test_histogram():
 
 def test_histogram_implicit_units():
     # see https://github.com/yt-project/unyt/issues/465
-    arr = np.random.normal(size=1000) * cm
+    rng = np.random.default_rng()
+    arr = rng.normal(size=1000) * cm
     counts, bins = np.histogram(arr, bins=10, range=(arr.min().value, arr.max().value))
     assert type(counts) is np.ndarray
     assert bins.units == arr.units
 
 
 def test_histogram2d():
-    x = np.random.normal(size=100) * cm
-    y = np.random.normal(loc=10, size=100) * s
+    rng = np.random.default_rng()
+    x = rng.normal(size=100) * cm
+    y = rng.normal(loc=10, size=100) * s
     counts, xbins, ybins = np.histogram2d(x, y)
     assert counts.ndim == 2
     assert xbins.units == x.units
@@ -512,9 +647,10 @@ def test_histogram2d():
 
 
 def test_histogramdd():
-    x = np.random.normal(size=100) * cm
-    y = np.random.normal(size=100) * s
-    z = np.random.normal(size=100) * g
+    rng = np.random.default_rng()
+    x = rng.normal(size=100) * cm
+    y = rng.normal(size=100) * s
+    z = rng.normal(size=100) * g
     counts, (xbins, ybins, zbins) = np.histogramdd((x, y, z))
     assert counts.ndim == 3
     assert xbins.units == x.units
@@ -523,23 +659,26 @@ def test_histogramdd():
 
 
 def test_histogram_bin_edges():
-    arr = np.random.normal(size=1000) * cm
+    rng = np.random.default_rng()
+    arr = rng.normal(size=1000) * cm
     bins = np.histogram_bin_edges(arr)
     assert type(bins) is unyt_array
     assert bins.units == arr.units
 
 
 def test_concatenate():
-    x1 = np.random.normal(size=100) * cm
-    x2 = np.random.normal(size=100) * cm
+    rng = np.random.default_rng()
+    x1 = rng.normal(size=100) * cm
+    x2 = rng.normal(size=100) * cm
     res = np.concatenate((x1, x2))
     assert res.units == cm
     assert res.shape == (200,)
 
 
 def test_concatenate_different_units():
-    x1 = np.random.normal(size=100) * cm
-    x2 = np.random.normal(size=100) * s
+    rng = np.random.default_rng()
+    x1 = rng.normal(size=100) * cm
+    x2 = rng.normal(size=100) * s
     with pytest.raises(
         UnitInconsistencyError,
         match=(
@@ -698,7 +837,7 @@ def test_append_inconsistent_units():
 def test_asfarray():
     x1 = np.eye(3, dtype="int64") * cm
 
-    x2 = np.asfarray(x1)
+    x2 = np.asfarray(x1)  # noqa: NPY201
     assert type(x2) is unyt_array
     assert x2.units == cm
     assert x2.dtype == "float64"
@@ -788,46 +927,47 @@ def test_fft_shift(func):
     assert res.units == cm
 
 
-@pytest.mark.filterwarnings("ignore:`trapz` is deprecated. Use `scipy.*")
-def test_trapz_no_x():
+if NUMPY_VERSION >= Version("2.0.0dev0"):
+    _trapezoid_func = np.trapezoid
+else:
+    _trapezoid_func = np.trapz
+
+
+def test_trapezoid_no_x():
     y = [0, 1, 2, 3] * cm
-    res = np.trapz(y)
+    res = _trapezoid_func(y)
     assert type(res) is unyt_quantity
     assert res.units == cm
 
 
-@pytest.mark.filterwarnings("ignore:`trapz` is deprecated. Use `scipy.*")
-def test_trapz_with_raw_x():
+def test_trapezoid_with_raw_x():
     y = [0, 1, 2, 3] * cm
     x = [0, 1, 2, 3]
-    res = np.trapz(y, x)
+    res = _trapezoid_func(y, x)
     assert type(res) is unyt_quantity
     assert res.units == cm
 
 
-@pytest.mark.filterwarnings("ignore:`trapz` is deprecated. Use `scipy.*")
-def test_trapz_with_unit_x():
+def test_trapezoid_with_unit_x():
     y = [0, 1, 2, 3] * cm
     x = [0, 1, 2, 3] * s
-    res = np.trapz(y, x)
+    res = _trapezoid_func(y, x)
     assert type(res) is unyt_quantity
     assert res.units == cm * s
 
 
-@pytest.mark.filterwarnings("ignore:`trapz` is deprecated. Use `scipy.*")
-def test_trapz_with_raw_dx():
+def test_trapezoid_with_raw_dx():
     y = [0, 1, 2, 3] * cm
     dx = 2.0
-    res = np.trapz(y, dx=dx)
+    res = _trapezoid_func(y, dx=dx)
     assert type(res) is unyt_quantity
     assert res.units == cm
 
 
-@pytest.mark.filterwarnings("ignore:`trapz` is deprecated. Use `scipy.*")
-def test_trapz_with_unit_dx():
+def test_trapezoid_with_unit_dx():
     y = [0, 1, 2, 3] * cm
     dx = 2.0 * s
-    res = np.trapz(y, dx=dx)
+    res = _trapezoid_func(y, dx=dx)
     assert type(res) is unyt_quantity
     assert res.units == cm * s
 
@@ -991,6 +1131,16 @@ def test_copyto_edge_cases():
     assert type(y) is np.ndarray
 
 
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"), reason="astype is new in numpy 2.0"
+)
+def test_astype():
+    x = np.array([1, 2, 3], dtype="int64") * cm
+    res = np.astype(x, "int32")
+    assert type(res) is unyt_array
+    assert res.units == cm
+
+
 def test_meshgrid():
     x = [1, 2, 3] * cm
     y = [1, 2, 3] * s
@@ -1252,19 +1402,6 @@ def test_eigvals(func):
     assert w.units == cm
 
 
-def test_linalg_svd():
-    a = (np.random.randn(9, 6) + 1j * np.random.randn(9, 6)) * cm
-    u, s, vh = np.linalg.svd(a)
-    assert type(u) is np.ndarray
-    assert type(vh) is np.ndarray
-    assert type(s) is unyt_array
-    assert s.units == cm
-
-    s = np.linalg.svd(a, compute_uv=False)
-    assert type(s) is unyt_array
-    assert s.units == cm
-
-
 def test_savetxt(tmp_path):
     a = [1, 2, 3] * cm
     with pytest.raises(
@@ -1402,6 +1539,68 @@ def test_unique():
     assert res.units == cm
 
 
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"), reason="unique_all is new in numpy 2.0"
+)
+def test_unique_all():
+    q = np.arange(9).reshape(3, 3) * cm
+    values, indices, inverse_indices, counts = np.unique(
+        q,
+        return_index=True,
+        return_inverse=True,
+        return_counts=True,
+        equal_nan=False,
+    )
+    res = np.unique_all(q)
+    assert len(res) == 4
+    assert_array_equal_units(res.values, values)
+    assert_array_equal_units(res.indices, indices)
+    assert_array_equal_units(res.inverse_indices, inverse_indices)
+    assert_array_equal_units(res.counts, counts)
+
+
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"), reason="unique_counts is new in numpy 2.0"
+)
+def test_unique_counts():
+    q = np.arange(9).reshape(3, 3) * cm
+    values, counts = np.unique(
+        q,
+        return_counts=True,
+        equal_nan=False,
+    )
+    res = np.unique_counts(q)
+    assert len(res) == 2
+    assert_array_equal_units(res.values, values)
+    assert_array_equal_units(res.counts, counts)
+
+
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"), reason="unique_inverse is new in numpy 2.0"
+)
+def test_unique_inverse():
+    q = np.arange(9).reshape(3, 3) * cm
+    values, inverse_indices = np.unique(
+        q,
+        return_inverse=True,
+        equal_nan=False,
+    )
+    res = np.unique_inverse(q)
+    assert len(res) == 2
+    assert_array_equal_units(res.values, values)
+    assert_array_equal_units(res.inverse_indices, inverse_indices)
+
+
+@pytest.mark.skipif(
+    NUMPY_VERSION < Version("2.0.0dev0"), reason="unique_values is new in numpy 2.0"
+)
+def test_unique_values():
+    q = np.arange(9).reshape(3, 3) * cm
+    values = np.unique(q, equal_nan=False)
+    res = np.unique_values(q)
+    assert_array_equal_units(res, values)
+
+
 def test_take():
     a = [1, 2, 3] * cm
     res = np.take(a, [0, 1])
