@@ -4,7 +4,6 @@ A registry for units that can be added to and modified.
 
 """
 
-
 import copy
 import json
 from functools import lru_cache
@@ -185,6 +184,8 @@ class UnitRegistry:
             )
 
         del self.lut[symbol]
+        if symbol in self._unit_object_cache:
+            del self._unit_object_cache[symbol]
 
     def modify(self, symbol, base_value):
         """
@@ -216,6 +217,8 @@ class UnitRegistry:
             new_dimensions = self.lut[symbol][1]
 
         self.lut[symbol] = (float(base_value), new_dimensions) + self.lut[symbol][2:]
+        if symbol in self._unit_object_cache:
+            del self._unit_object_cache[symbol]
 
     def keys(self):
         """
@@ -266,8 +269,18 @@ class UnitRegistry:
         return type(self)(lut=lut)
 
 
+class _NonModifiableUnitRegistry(UnitRegistry):
+    """The class of the default unit registry"""
+
+    def modify(self, symbol, base_value):
+        raise TypeError("Units from unyt's default registry cannot be modified.")
+
+    def remove(self, symbol):
+        raise TypeError("Units from unyt's default registry cannot be removed.")
+
+
 #: The default unit registry
-default_unit_registry = UnitRegistry()
+default_unit_registry = _NonModifiableUnitRegistry()
 
 
 def _lookup_unit_symbol(symbol_str, unit_symbol_lut):
